diff data/model/Model.h @ 1767:aa0b56d72f27

Ensure the right model ID gets sent with the signal for alignment changes
author Chris Cannam
date Thu, 18 Jul 2019 13:17:49 +0100
parents ee7fd2c01d87
children 13bd41bd8a17
line wrap: on
line diff
--- a/data/model/Model.h	Wed Jul 17 14:24:51 2019 +0100
+++ b/data/model/Model.h	Thu Jul 18 13:17:49 2019 +0100
@@ -292,10 +292,14 @@
 
     /**
      * Emitted when the completion percentage changes for the
      * calculation of this model's alignment model.
      */
     void alignmentCompletionChanged(ModelId myId);
 
+private slots:
+    void alignmentModelCompletionChanged(ModelId);
+    
 protected:
     Model() :
         m_extendTo(0) { }
@@ -292,10 +292,14 @@
     /**
      * Emitted when the completion percentage changes for the
-     * calculation of this model's alignment model.
+     * calculation of this model's alignment model. (The ModelId
+     * provided is that of this model, not the alignment model.)
      */
     void alignmentCompletionChanged(ModelId myId);